FlutterTwitch class

Constructors

FlutterTwitch()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String
getter/setter pair
TWITCH_CLIENT_ID ↔ String
getter/setter pair
TWITCH_CLIENT_SECRET ↔ String
getter/setter pair
TWITCH_REDIRECT_URI ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

getAccessToken → String?
no setter
getUserAccessToken → String?
no setter
instance → FlutterTwitch
no setter
users → Users
no setter

Static Methods

initialize({required String twitchClientId, required String twitchClientSecret, required String twitchRedirectUri, String? scope}) → dynamic
setAccessToken(String accessToken) → dynamic
setUserAccessToken(String accessToken) → dynamic